@@ -176,12 +176,12 @@ url = %s""" % (self.debug,
 
         c, _ = self._exec(["gnocchi-metricd", "--config-file=%s" % conffile],
                           wait_for_line="metrics wait to be processed")
-        self.addCleanup(self._kill, c.pid)
+        self.addCleanup(self._kill, c)
 
         c, _ = self._exec(["gnocchi-statsd", "--config-file=%s" % conffile],
                           wait_for_line=("(Resource .* already exists"
                                          "|Created resource )"))
-        self.addCleanup(self._kill, c.pid)
+        self.addCleanup(self._kill, c)
 
         c, _ = self._exec([
             "uwsgi",
@@ -196,7 +196,7 @@ url = %s""" % (self.debug,
             "--add-header", "Connection: close",
             "--pyargv", "--config-file=%s" % conffile,
         ], wait_for_line="WSGI app 0 \(mountpoint=''\) ready")
-        self.addCleanup(self._kill, c.pid)
+        self.addCleanup(self._kill, c)
 
         self.http_url = "http://localhost:%d" % self.port
 
