@@ -15,6 +15,7 @@
 
 from distutils import spawn
 import logging
+import mock
 import os
 import six
 import socket
@@ -23,6 +24,7 @@ import fixtures
 import requests
 import testtools
 
+from pifpaf import drivers
 from pifpaf.drivers import aodh
 from pifpaf.drivers import ceph
 from pifpaf.drivers import consul
@@ -70,6 +72,18 @@ class TestDrivers(testtools.TestCase):
     def _run(self, cmd):
         self.assertEqual(0, os.system(cmd + " >/dev/null 2>&1"))
 
+    def test_stuck_process(self):
+        d = drivers.Driver(debug=True)
+        c, _ = d._exec(["bash", "-c",
+                        "trap ':' TERM ; echo start; sleep 10000"],
+                       wait_for_line="start")
+        with mock.patch.object(drivers.LOG, "warning") as w:
+            d._kill(c)
+            w.assert_called_once()
+        self.assertNotEqual(None, c.poll())
+
+    @testtools.skip("Driver need rework, it won't work with travis or "
+                    "Ubuntu xenial or Debian strech package")
     @testtools.skipUnless(spawn.find_executable("elasticsearch"),
                           "elasticsearch not found")
     def test_elasticsearch(self):
@@ -272,7 +286,8 @@ class TestDrivers(testtools.TestCase):
     @testtools.skipUnless(spawn.find_executable("swift-proxy-server"),
                           "Swift not found")
     def test_gnocchi_with_existing_swift(self):
-        self.useFixture(swift.SwiftDriver())
+        tmp_rootdir = self._get_tmpdir_for_xattr()
+        self.useFixture(swift.SwiftDriver(tmp_rootdir=tmp_rootdir))
         self.useFixture(gnocchi.GnocchiDriver(
             storage_url=os.getenv("PIFPAF_URL")))
         self.assertEqual("gnocchi://localhost:8041",
@@ -305,13 +320,8 @@ class TestDrivers(testtools.TestCase):
                           "Ceph client not found")
     def test_gnocchi_with_existing_ceph(self):
         port = gnocchi.GnocchiDriver.DEFAULT_PORT + 10
-        tempdir = self.useFixture(fixtures.TempDir()).path
-
-        ceph_driver = ceph.CephDriver()
-        try:
-            ceph_driver._ensure_xattr_support(tempdir)
-        except RuntimeError as e:
-            self.skipTest(str(e))
+        tmp_rootdir = self._get_tmpdir_for_xattr()
+        ceph_driver = ceph.CephDriver(tmp_rootdir=tmp_rootdir)
         self.useFixture(ceph_driver)
 
         ceph_driver._exec(["rados", "-c", os.getenv("CEPH_CONF"), "mkpool",
@@ -368,14 +378,8 @@ class TestDrivers(testtools.TestCase):
     @testtools.skipUnless(spawn.find_executable("ceph"),
                           "Ceph client not found")
     def test_ceph(self):
-        tempdir = self.useFixture(fixtures.TempDir()).path
-        driver = ceph.CephDriver()
-        try:
-            driver._ensure_xattr_support(tempdir)
-        except RuntimeError as e:
-            self.skipTest(str(e))
-
-        a = self.useFixture(driver)
+        tmp_rootdir = self._get_tmpdir_for_xattr()
+        a = self.useFixture(ceph.CephDriver(tmp_rootdir=tmp_rootdir))
         self.assertEqual("ceph://localhost:%d" % a.port,
                          os.getenv("PIFPAF_URL"))
         self.assertIn("ceph.conf", os.getenv("CEPH_CONF"))
@@ -449,7 +453,8 @@ class TestDrivers(testtools.TestCase):
     @testtools.skipUnless(spawn.find_executable("swift-proxy-server"),
                           "Swift not found")
     def test_swift(self):
-        a = self.useFixture(swift.SwiftDriver())
+        tmp_rootdir = self._get_tmpdir_for_xattr()
+        a = self.useFixture(swift.SwiftDriver(tmp_rootdir=tmp_rootdir))
         self.assertEqual("http://localhost:8080/auth/v1.0",
                          os.getenv("PIFPAF_SWIFT_AUTH_URL"))
         self.assertEqual(8080, a.port)
@@ -462,3 +467,15 @@ class TestDrivers(testtools.TestCase):
         self.assertEqual(
             "swift://test%3Atester:testing@localhost:8080/auth/v1.0",
             os.getenv("PIFPAF_URL"))
+
+    def _get_tmpdir_for_xattr(self):
+        tmp_rootdir = os.getenv("TMPDIR_FOR_XATTR")
+        # NOTE(sileht): Don't skip test if user have explicitly set a directory
+        if not tmp_rootdir:
+            try:
+                d = drivers.Driver(tmp_rootdir=tmp_rootdir)
+                self.useFixture(d)
+                d._ensure_xattr_support()
+            except RuntimeError as e:
+                self.skipTest(str(e))
+        return tmp_rootdir
